@@ -5,10 +5,8 @@ import traceback
 import time
 import random
 import string
-from typing import TYPE_CHECKING
-
 from markupsafe import Markup
-
+from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from pyhtmlgui.lib.observable import Observable
 from pyhtmlgui.pyhtmlguiInstance import PyHtmlGuiInstance
@@ -128,9 +126,16 @@ class PyHtmlView:
             self.call_javascript("pyhtmlgui.remove_element", [self.uid], skip_results=True)
         if self.is_visible is True:
             self.set_visible(False)
-        self.parent._remove_child(self)
-        for child in self._children:
-            child.delete(remove_from_dom=False)
+        try:
+            self.parent._remove_child(self)
+        except:
+            pass
+
+        for child in [c for c in self._children]:
+            try:
+                child.delete(remove_from_dom=False)
+            except:
+                pass
 
     def set_visible(self, visible: bool) -> None:
         """
@@ -147,9 +152,11 @@ class PyHtmlView:
                     observable().detach_observer(target())  # resolve weak references
                 except Exception:
                     pass
-            for child in self._children:
-                if child.is_visible is True:
+            for child in [c for c in self._children if c.is_visible is True]:
+                try:
                     child.set_visible(False)
+                except:
+                    pass
         else:
             self.is_visible = True
             for observable, target in self._observables:
@@ -191,8 +198,11 @@ class PyHtmlView:
         if self._subject is None:  # Observed object died before render
             return None
 
-        for child in self._children:
-            child.__was_rendered = False
+        for child in [c for c in self._children]:
+            try:
+                child.__was_rendered = False
+            except:
+                pass
 
         if self.is_visible is False:
             self.set_visible(True)
@@ -208,7 +218,12 @@ class PyHtmlView:
             print(msg)
 
         # set children that have not been rendered in last pass to invisible
-        [c.set_visible(False) for c in self._children if c.__was_rendered is False and c.is_visible is True]
+        children = [c for c in self._children if c.__was_rendered is False and c.is_visible is True]
+        for child in children:
+            try:
+                child.set_visible(False)
+            except:
+                pass
 
         self.__was_rendered = True
         self._subject = None  # remove hard reference to subject, it may die now
@@ -218,7 +233,10 @@ class PyHtmlView:
         self._children.add(child)
 
     def _remove_child(self, child: PyHtmlView) -> None:
-        self._children.remove(child)
+        try:
+            self._children.remove(child)
+        except: # ignore if weak ref faild to resolve
+            pass
 
     def add_observable(self, subject: Observable, target_function: typing.Callable = None) -> None:
         try:
